@@ -473,10 +473,12 @@ refresh_model (EelMimeApplicationChooser *chooser)
 
 		gtk_tree_view_column_set_visible (column, FALSE);
 		gtk_list_store_append (chooser->details->model, &iter);
+		gchar *name = g_strdup_printf ("<i>%s</i>", _("No applications selected"));
 		gtk_list_store_set (chooser->details->model, &iter,
-				    COLUMN_NAME, _("<i>No applications selected</i>"),
+				    COLUMN_NAME, name,
 				    COLUMN_ID, NULL,
 				    -1);
+		g_free (name);
 
 		gtk_tree_selection_set_mode (selection, GTK_SELECTION_NONE);
 	}
@@ -536,7 +538,9 @@ set_uri_and_mime_type (EelMimeApplicationChooser *chooser,
 	}
 
 	/* first %s is filename, second %s is mime-type description */
-	label = g_strdup_printf (_("Select an application to open <i>%s</i> and others of type \"%s\""), name, chooser->details->mime_description);
+	gchar *emname = g_strdup_printf ("<i>%s</i>", name);
+	label = g_strdup_printf (_("Select an application to open %s and others of type \"%s\""), emname, chooser->details->mime_description);
+	g_free (emname);
 	
 	gtk_label_set_markup (GTK_LABEL (chooser->details->label), label);
 
